# DeliveryScheduleFrequency

Specifies the frequency for delivery schedule 

## Enum

* `WEEKLY` (value: `'Weekly'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


